Manager.biosql.biosql.MySQLBioSQL

Usage

Manager.biosql.biosql.MySQLBioSQL(
    database_path, database_name="Template-BioSQL-MySQL.db"
)

Methods

Name Description
__init__() This class inherits the BaseBioSQL class. It uses the base methods to load schema, load taxonomy (NCBI, ITIS),

__init__()

This class inherits the BaseBioSQL class. It uses the base methods to load schema, load taxonomy (NCBI, ITIS),

Usage

__init__(database_path, database_name="Template-BioSQL-MySQL.db")

and create/copy template MySQL databases loaded with biosql schema and/or taxonomy data. The MySQL driver for BioPython’s BioSQL databases is the most developed. It can utilize the PhyloDB schema extension and scripts as well as the standard BioSQL schema and scripts.

Parameters
database_path: str.

The relative path to the database.

database_name: str. = "Template-BioSQL-MySQL.db"
The name of the database.