Manager.biosql.biosql.SQLiteBioSQL

Usage

Manager.biosql.biosql.SQLiteBioSQL(
    database_name=None,
    proj_mana=ProjectManagement,
    template_name="Template-BioSQL-SQLite.db",
    **kwargs
)

Methods

Name Description
__init__() This class inherits the BaseBioSQL class.
copy_template_database() This method copies a template sqlite biosql database into the destination folder.
create_template_database() Creates a template database by uploading SQLite schema and NCBI taxonomy.
load_sqlite_schema() Loads an SQLite biosql schema into a database file.
load_sqlite_taxonomy() Load an SQLite biosql database with taxonomy information. This will only work for NCBI. There is not any
update_sqlite_taxonomy() Update an SQLite biosql database with taxonomy information.
upload_files() Uploads files into a BioSQL database.

__init__()

This class inherits the BaseBioSQL class.

Usage

__init__(
    database_name=None,
    proj_mana=ProjectManagement,
    template_name="Template-BioSQL-SQLite.db",
    **kwargs
)

It uses the base methods to load schema, load taxonomy (NCBI), and create/copy template SQLite databases loaded with biosql schema and/or taxonomy data.

Parameters
database_name: str. = None

The name of the database.

proj_mana: ProjectManagement. = ProjectManagement

A configuration variable for connecting projects.

template_name: str. = "Template-BioSQL-SQLite.db"

The name of the template.

kwargs: dict. = {}
Key-word arguments.

copy_template_database()

This method copies a template sqlite biosql database into the destination folder.

Usage

copy_template_database(destination)
Parameters
destination: str.
The path to copy the template into.

create_template_database()

Creates a template database by uploading SQLite schema and NCBI taxonomy.

Usage

create_template_database()

load_sqlite_schema()

Loads an SQLite biosql schema into a database file.

Usage

load_sqlite_schema()

load_sqlite_taxonomy()

Load an SQLite biosql database with taxonomy information. This will only work for NCBI. There is not any

Usage

load_sqlite_taxonomy()

support for the SQLite PhyloDB.


update_sqlite_taxonomy()

Update an SQLite biosql database with taxonomy information.

Usage

update_sqlite_taxonomy()

upload_files()

Uploads files into a BioSQL database.

Usage

upload_files(seqtype, filetype, upload_path, upload_list=None)
Parameters
seqtype: str.

The type of sequence (rna, protein, genomic).

filetype: str.

The type of file used to load into the BioSQL database (usually genbannk).

upload_path: str.

The relative path to the database to be uploaded to.

upload_list: list. = None
A list of files to upload.