Manager.data_management.DataMana

Usage

Manager.data_management.DataMana(
    config_file=None, pipeline=None, new=False, start=False, **kwargs
)

Methods

Name Description
__init__() Initialize the attributes that can be used as keys in the config_file.
blast() Run BLAST analysis.
configure() Use YAML configuration in order to initialize different classes.

__init__()

Initialize the attributes that can be used as keys in the config_file.

Usage

__init__(config_file=None, pipeline=None, new=False, start=False, **kwargs)
Parameters
config_file: str | Path | None = None

Path to YAML configuration file.

pipeline: str | None = None

Name of the pipeline to use (e.g., ‘Ortho_CDS_1’).

new: bool = False

Flag indicating if this is a new pipeline setup.

start: bool = False

Flag to start the pipeline immediately after initialization.

kwargs: dict = {}
Additional keyword arguments for configuration.

blast()

Run BLAST analysis.

Usage

blast(proj_mana, blast_config)

Executes BLAST analysis using the provided project management and BLAST configuration.

Parameters
proj_mana: ProjectManagement

Project management instance for organizing BLAST results.

blast_config: dict
Configuration dictionary for BLAST parameters.

configure()

Use YAML configuration in order to initialize different classes.

Usage

configure(config_file)

Reads a YAML configuration file and initializes various classes (ProjectManagement, OrthoBlastN, GenBank, etc.) based on the configuration.

Parameters
config_file: str | Path
A YAML file that is used to create a dictionary(kwargs) for each class.