Manager.management.RepoManagement

Usage

Manager.management.RepoManagement(
    repo,
    user=None,
    home=os.getcwd(),
    new_user=False,
    new_repo=False,
    **kwargs
)

Methods

Name Description
__init__() This is the Repository Management class, which inherits the Management base class. This class has to be paired

__init__()

This is the Repository Management class, which inherits the Management base class. This class has to be paired

Usage

__init__(
    repo,
    user=None,
    home=os.getcwd(),
    new_user=False,
    new_repo=False,
    **kwargs
)

with a repository name. It gives the option of creating a filesystem for a new user and a new repository using cookiecutter.

This class maps the named repository, which includes top level access to front facing web servers, important documents, and the top level users directory.

Parameters
repo: str

The name of the repository.

user: str | None = None

The name of the current user if any.

home: str | Path = os.getcwd()

The home path of the repository.

new_user: bool = False

Flag for creating a new user.

new_repo: bool = False
Flag for creating a new repository.