OrthoEvolDevelopmentWarning

This is the OrthoEvol developmental code warning subclass.

Usage

OrthoEvolDevelopmentWarning()

This warning is for alpha or beta level code which is released as part of the standard releases to mark sub-modules or functions for early adopters to test & give feedback. Code issuing this warning is likely to change or removed in a subsequent release of this package. Such code should NOT be used for production/stable code.