Orthologs.Align.Guidance2Commandline

Command line wrapper for GUIDANCE2.

Usage

Orthologs.Align.Guidance2Commandline(
    cmd="guidance",
    align=True,
    **kwargs,
)

http://guidance.tau.ac.il/ver2/

>>> from Bio.Align.Applications import Guidance2Commandline

You would typically run the command line with clustalomega_cline() or via the Python subprocess module, as described in the Biopython tutorial.

Sela, I., Ashkenazy, H., Katoh, K. and Pupko, T. (2015)
GUIDANCE2: accurate detection of unreliable alignment regions accounting for the uncertainty of multiple parameters.
Nucleic Acids Research, 2015 Jul 1; 43 (Web Server issue): W7-W14.; doi: 10.1093/nar/gkq443

Landan, G., and D. Graur. (2008).
Local reliability measures from sets of co-optimal multiple sequence alignments.
Pac Symp Biocomput 13:15-24

Methods

Name Description
__init__() Initialize GUIDANCE2 command line wrapper.

__init__()

Initialize GUIDANCE2 command line wrapper.

Usage

__init__(cmd="guidance", align=True, **kwargs)
Parameters
cmd: str = "guidance"

Command name for GUIDANCE2 executable.

align: bool = True

Flag to determine if alignment mode is used.

kwargs: object = {}
Additional parameters for GUIDANCE2 configuration.