Orthologs.Phylogenetics.PAML.CodemlRun

Run PAML’s codeml program using Biopython’s codeml wrapper.

Usage

Orthologs.Phylogenetics.PAML.CodemlRun(
    P2N_alignment,
    iqtree_newick,
    control_file="codeml-8-11-2017.ctl",
    home=os.getcwd()
)

This class sets up the necessary files and configuration for running codeml analysis on a PAL2NAL alignment and IQTree newick tree.

Methods

Name Description
__init__() Initialize CodemlRun class.
control_setup() Set up the codeml control file from template.

__init__()

Initialize CodemlRun class.

Usage

__init__(
    P2N_alignment,
    iqtree_newick,
    control_file="codeml-8-11-2017.ctl",
    home=os.getcwd()
)
Parameters
P2N_alignment: str

Path to PAL2NAL alignment file.

iqtree_newick: str

Path to IQTree newick tree file.

control_file: str = "codeml-8-11-2017.ctl"

Name of the codeml control file template.

home: str | Path = os.getcwd()
Working directory for codeml execution.

control_setup()

Set up the codeml control file from template.

Usage

control_setup(control_template)

Reads the control file template, prints options, and writes a gene-specific control file.

Parameters
control_template: str
Path to the codeml control file template.