Tools.pbs.Qstat

Usage

Tools.pbs.Qstat(
    job_id,
    wait_time=120,
    **kwargs,
)

Methods

Name Description
countdown() This method takes a wait time and preforms a countdown in the terminal
plot_data() This method plots qstat data over time. Three different interactive plotly
watch() This watch method is directly used by the end user to collect data on the

countdown()

This method takes a wait time and preforms a countdown in the terminal

Usage

countdown(wait_time=None)

during the wait period.

Parameters
wait_time: int. = None
The time in seconds to wait.

plot_data()

This method plots qstat data over time. Three different interactive plotly

Usage

plot_data(data_file)

line graphs are created. One with mem and vmem, one with cpu percentage, and one with cpu time.

Parameters
data_file: str.
A csv file that contains qstat data.

watch()

This watch method is directly used by the end user to collect data on the

Usage

watch(count=None, max_count=None)

target job over time.

Parameters
count: int. = None

The count of qstat data points collected.

python_datetime: datetime.

A date time that will be added to the qstat data.

max_count: int. = None
The maximum number of times that Qstat will collect data points on the target job.