Tools.slackify.Slackify

Send messages or milestones to a slack channel.

Usage

Tools.slackify.Slackify(
    slackconfig="slackconfig.cfg",
    cfg=True,
)

Methods

Name Description
__init__() Configure Slackify.
list_channels() List all channels for your slack organization.
list_users() List all users for your slack organization.
log2slack() Send a formatted text string to slack similar to logging.
send_msg() Post a message to slack channel.
upload_file() Upload files (text/pdf/docx/log/image) to a slack channel.

__init__()

Configure Slackify.

Usage

__init__(slackconfig="slackconfig.cfg", cfg=True)
Parameters
slackconfig="slackconfig.cfg"

Path to config file.

cfg=True
Flag that is default True.

list_channels()

List all channels for your slack organization.

Usage

list_channels()

list_users()

List all users for your slack organization.

Usage

list_users()

log2slack()

Send a formatted text string to slack similar to logging.

Usage

log2slack()

send_msg()

Post a message to slack channel.

Usage

send_msg(channel, message)

Send a message to a user using <@username>

Parameters
channel

Name of the channel to send a message to.

message
Message to send to a channel.

upload_file()

Upload files (text/pdf/docx/log/image) to a slack channel.

Usage

upload_file(file, channel)
Parameters
file

Path to a file to upload.

channel
Name of the channel to upload the file to.