resources.package_resource_path()

Return a filesystem path for a resource in an installed package.

Usage

resources.package_resource_path(
    package,
    resource_name="",
)

OrthoEvol is configured as not zip-safe, so its installed resources are real files and can be passed to tools that require filesystem paths.