Manager.biosql.biosql.BaseBioSQL
Usage
Manager.biosql.biosql.BaseBioSQL(
database_name,
template_name="",
project=None,
project_path=None,
proj_mana=ProjectManagement,
**kwargs
)Methods
| Name | Description |
|---|---|
| __init__() | This is the base BioSQL class. It provides a general framework for managing the BioSQL workflow. Higher level |
| configure_new_database() | This script is a framework for loading the various schemas, the NCBI taxonomy (biosql-db), and the ITIS |
| create_executable_scripts() | Change permissions of the BioSQL perl scripts to make them executable. |
__init__()
This is the base BioSQL class. It provides a general framework for managing the BioSQL workflow. Higher level
Usage
__init__(
database_name,
template_name="",
project=None,
project_path=None,
proj_mana=ProjectManagement,
**kwargs
)classes provide more specific functionality related to the various BioSQL supported database types. Taxonomy data can be found at: NCBI: ftp://ftp.ncbi.nlm.nih.gov/pub/taxonomy ITIS: http://www.itis.gov/downloads/
Parameters
database_name: str.-
The name of the database.
template_name: str. = ""-
The name of the NCBI taxonomy database that will be copied for use.
project: str. = None-
The name of the project, if Project Management isn’t utilized.
project_path: str. = None-
Where the project is located if Project Management isn’t utilized.
proj_mana: ProjectManagement. = ProjectManagement-
A configuration variable for connecting projects.
kwargs: dict. = {}- Key-word arguments.
configure_new_database()
This script is a framework for loading the various schemas, the NCBI taxonomy (biosql-db), and the ITIS
Usage
configure_new_database(cmd, schema_file=None)taxonomy (phylo-db) into a database.
Parameters
cmd: str.-
The bash command to use.
schema_file: str. = None- The schema file for creating a BioSQL or PhyloDB
Returns
str.- Returns the Output and the Error messages.
create_executable_scripts()
Change permissions of the BioSQL perl scripts to make them executable.
Usage
create_executable_scripts()