Manager.management.Management
Usage
Manager.management.Management(
repo=None, home=os.getcwd(), new_repo=False, **kwargs
)Methods
| Name | Description |
|---|---|
| __init__() | This is a base class for directory management. |
__init__()
This is a base class for directory management.
Usage
__init__(repo=None, home=os.getcwd(), new_repo=False, **kwargs)It maps the directories of the OrthoEvol-Script package using the pathlib module and turns the names of each important directory into a pathlike object. The base class gives the option of creating a new repository with cookiecutter.
Parameters
repo: str | None = None-
The name of the new repository to be created.
home: str | Path = os.getcwd()-
The home of the file calling this name. When creating a new repository, it is best to explicitly name the home path.
new_repo: bool = False- Triggers cookiecutter to create a new repository.