Manager.management.ProjectManagement
Usage
Manager.management.ProjectManagement(
repo,
user,
project,
research=None,
research_type=None,
app=None,
home=os.getcwd(),
new_project=False,
new_research=False,
new_app=False,
**kwargs
)Methods
| Name | Description |
|---|---|
| __init__() | This is the Project Management class, which manages the directories of |
__init__()
This is the Project Management class, which manages the directories of
Usage
__init__(
repo,
user,
project,
research=None,
research_type=None,
app=None,
home=os.getcwd(),
new_project=False,
new_research=False,
new_app=False,
**kwargs
)the current project. Each project requires a repository, user, and project name. It gives the option of starting a new type of research within an existing project. An application directory for the specific research/dataset can also be generated
It gives access to the project directories including index files, the raw data, the processed data, the project db_config_file, and the web files for serving data.
Parameters
repo: str-
The name of the repository.
user: str-
The name of the current user if any.
project: str-
The name of the current project if any.
research: str | None = None-
The name of the current type of research if any.
research_type: str | None = None-
The type of research (e.g., ‘comparative_genetics’, ‘public’, ‘private’).
app: str | None = None-
The name of the application for the research.
home: str | Path = os.getcwd()-
The home path of the repository.
new_project: bool = False-
Flag for creating a new project.
new_research: bool = False-
Flag for creating new research under a project.
new_app: bool = False- Flag for creating a new web app under a research target.