Manager.management.WebsiteManagement
Usage
Manager.management.WebsiteManagement(
repo,
website,
host="0.0.0.0",
port="5252",
home=os.getcwd(),
new_website=False,
create_admin=False,
**kwargs
)Methods
| Name | Description |
|---|---|
| __init__() | This is the Website Management class, which installs a template for Flask using cookiecutter. The |
| stop_server() | Stop the server running the website. |
__init__()
This is the Website Management class, which installs a template for Flask using cookiecutter. The
Usage
__init__(
repo,
website,
host="0.0.0.0",
port="5252",
home=os.getcwd(),
new_website=False,
create_admin=False,
**kwargs
)official cookiecutter-flask template (https://github.com/sloria/cookiecutter-flask) has been edited for our own purposes. This app class uses cookiecutter hooks to deploy the flask server.
Parameters
repo: str-
The name of the repository.
website: str-
The name of the website. Not a URL, so it doesn’t contain http://www.*.com. (e.g. for www.vallenger-genetics.ml this parameter would be ‘vallender-genetics’)
host: str = "0.0.0.0"-
The address to launch the flask app. Defaults to ‘0.0.0.0’.
port: str = "5252"-
The port to launch the flask app. Defaults to ‘5252’.
home: str | Path = os.getcwd()-
The home path of the repository.
new_website: bool = False-
Flag for creating a new website.
create_admin: bool = False- Flag for creating an admin user.
stop_server()
Stop the server running the website.
Usage
stop_server()