Orthologs.Blast.OrthoBlastN
OrthoBlastN provides a preconfigured and orthology optimized version
Usage
Orthologs.Blast.OrthoBlastN(
project="orthology-gpcr",
project_path=os.getcwd(),
method=1,
template=None,
save_data=True,
acc_file="gpcr.csv",
copy_from_package=True,
auto_start=False,
**kwargs
)of the BaseBlastN class.
Methods
| Name | Description |
|---|---|
| __init__() | This class inherits from the BaseBlastN class. |
| run() | Run the blast using a default configuration. |
__init__()
This class inherits from the BaseBlastN class.
Usage
__init__(
project="orthology-gpcr",
project_path=os.getcwd(),
method=1,
template=None,
save_data=True,
acc_file="gpcr.csv",
copy_from_package=True,
auto_start=False,
**kwargs
)This class utilizes it’s parent classes to search a standalone Blast database for specific orthologs of a gene using a query organism (usually human). The best hits from the Blast are filtered for the best option in order to get the most accuarate accession numbers for downstream analysis.
Parameters
project="orthology-gpcr"-
The project name (Default: ‘orthology-gpcr’)
project_path=os.getcwd()-
The path of the project (Default: ‘os.getcwd()’)
method=1-
Method used for blasting. (Default: 1)
template=None-
The accession file template.
save_data=True-
A flag for saving the post_blast data to an excel file.
acc_file="gpcr.csv"-
The accession file to use. (Default: ‘gpcr.csv’)
copy_from_package=True-
Copy the acc_file from the package. (Default: True)
kwargs={}
run()
Run the blast using a default configuration.
Usage
run()