Tools.parallel.Multiprocess
Use multiple processes with a function.
Usage
Tools.parallel.Multiprocess()Methods
| Name | Description |
|---|---|
| __init__() | Initialize variables that will be used later. |
| map_to_function() | Start a pool to run your function with a list. |
__init__()
Initialize variables that will be used later.
Usage
__init__()map_to_function()
Start a pool to run your function with a list.
Usage
map_to_function(function, iterable, procs=None)Parameters
function-
Input a python function.
iterable-
Input a list or dictionary to map to the function.
procs=None- The number of processors to use in the pool.