Tools.slurm.SlurmClient
Run one-shot Slurm submission and inspection commands.
Usage
Tools.slurm.SlurmClient()Methods
| Name | Description |
|---|---|
| active_jobs() | Return one snapshot of active jobs for a single user. |
| job_history() | Return the allocation-level accounting record for one job. |
| submit() | Submit an existing batch script and return its Slurm job ID. |
active_jobs()
Return one snapshot of active jobs for a single user.
Usage
active_jobs(user=None)job_history()
Return the allocation-level accounting record for one job.
Usage
job_history(job_id)submit()
Submit an existing batch script and return its Slurm job ID.
Usage
submit(script)