utilities.GenbankUtils
Usage
utilities.GenbankUtils()Methods
| Name | Description |
|---|---|
| __init__() | Various utilities to help with genbank specific functionality. |
| muli_fasta_add() | Add selected reference sequences in a multi-FASTA files. |
| multi_fasta_manipulator() | Manipulate reference sequences in multifasta files. |
| multi_fasta_remove() | Remove selected reference sequences in a multi-FASTA files. |
| multi_fasta_sort() | Sorts selected reference sequences in a multi-FASTA files. |
__init__()
Various utilities to help with genbank specific functionality.
Usage
__init__()muli_fasta_add()
Add selected reference sequences in a multi-FASTA files.
Usage
muli_fasta_add(target_file, man_file, output_file)Parameters
target_file: str.-
Target multi-FASTA file.
man_file: str.-
A multi-FASTA file with sequences used for appending to the target file.
output_file: str.- The name of the output multi-FASTA file.
Returns
str.- A multi-FASTA file with added sequences.
multi_fasta_manipulator()
Manipulate reference sequences in multifasta files.
Usage
multi_fasta_manipulator(
target_file, man_file, output_file, manipulation="remove"
)The original purpose was to filter files created by the GUIDANCE2 alignment program, but this function has been made in order to accommodate other situations as well.
Parameters
target_file: str.-
Target multi-FASTA file.
man_file: str.-
Sequences in a multi-FASTA file used for manipulation.
manipulation: str. = "remove"-
The type of manipulation. (remove, add, sort, tbd..)
output_file: str.- The name of the output multi-FASTA file.
Returns
str.- A multi-FASTA file that has been manipulated accordingly.
multi_fasta_remove()
Remove selected reference sequences in a multi-FASTA files.
Usage
multi_fasta_remove(target_file, man_file, output_file)Parameters
target_file: str.-
Target multi-FASTA file.
man_file: str.-
A multi-FASTA file with sequences used for removal from the the target file.
output_file: str.- The name of the output multi-FASTA file.
Returns
str.- A multi-FASTA file with removed sequences.
multi_fasta_sort()
Sorts selected reference sequences in a multi-FASTA files.
Usage
multi_fasta_sort(target_file, man_file, output_file)Parameters
target_file: str.-
Target multi-FASTA file.
man_file: str.-
A multi-FASTA file with sequences used for sorting the target file.
output_file: str.- The name of the output multi-FASTA file.
Returns
str.- A multi-FASTA file with sorted sequences.