utilities.OrthologUtils
Usage
utilities.OrthologUtils()Methods
| Name | Description |
|---|---|
| __init__() | Various utilities to help with ortholog specific functionality. |
| attribute_config() | Set or configure attributes. |
| standalone_config() | Configure a standalone project. |
__init__()
Various utilities to help with ortholog specific functionality.
Usage
__init__()attribute_config()
Set or configure attributes.
Usage
attribute_config(
cls, composer, checker, project=None, project_path=None, checker2=None
)Attribute Configuration takes an instance of a class and sets various attributes. The attributes are set by determining the type of configuration. The class attributes can be composed by another class, they can be set with a dictionary, or they can be set using the basic project template.
Parameters
cls: object.-
An instance of a class that will retain the attributes.
composer: object.-
A class that will yield attributes to the cls parameter.
checker: class-
A checker class used to check the type of the composer. Dictionary composers will be treated differently.
checker2: class | None = None-
An optional second checker class for additional type checking.
project: str. = None-
The name of the project.
project_path: str. = None- The relative path of the project.
Returns
object.- Returns the instance (cls) with new attributes.
standalone_config()
Configure a standalone project.
Usage
standalone_config(cls, project, project_path, custom=None)A standalone configuration uses the variables listed. These variables are either mapped to a basic project, used in a custom configuration, or they are mapped to some basic project directories with some custom options.
Parameters
cls: object.-
An instance of a class that will retain the attributes.
project: str.-
The name of the project.
project_path: str | Path-
The relative path of a project.
custom: dict | None = None- The custom flag which can be None or a dictionary.
Returns
object.- Returns the instance (cls) with new attributes.